# group settings for 'ws' (OPAL)
# https://its.cern.ch/jira/browse/NOAFS-501
# based on /afs/cern.ch/group/ws/group_env.sh
# modified for migration to cvmfs

export OPAL=/cvmfs/opal.cern.ch		##Define the top of the OPAL project tree
# In cvmfs we don't have the same structure as we did in AFS...
export otop="$OPAL"	##Define the top of the OPAL code tree
export opal="$OPAL"     ##Define the top of the OPAL project tree

## Generate OPAL symbols <version_xx>
version_opal=pro ; export version_opal
if [ -f "${otop}/utl/oversion.${version_opal}" ]; then
        source "${otop}/utl/oversion.${version_opal}"
else
        echo "Warning: oversion.${version_opal} does not exist!"
fi

OPAL_P_DB="${otop}/db"			  export OPAL_P_DB
cern="${OPAL}/cern" ;                     export cern
libver="pro" ;                            export libver
gksver="pro" ;                            export gksver

# set the hardware variable, needed for some scripts (ytofort, fort, link, ...)
HARDWARE=`${otop}/scripts/hardware` ;       export HARDWARE
if [ "$HARDWARE" = "i386slc3" ]; then
  OpalBinTag='/i386slc3'
elif [ "$HARDWARE" = "i386slc5" ]; then
  OpalBinTag='/i386slc5'
elif [ "$HARDWARE" = "amd64slc5" ]; then
  OpalBinTag='/amd64slc5'
elif [ "$HARDWARE" = "i386slc6" -o "$HARDWARE" = "amd64slc6" ]; then
  OpalBinTag='/i386slc6'
  PATH="${PATH}:${cern}${OpalBinTag}/${libver}/bin"
elif [ "$HARDWARE" = "i386cc7" -o "$HARDWARE" = "amd64cc7" ]; then
  OpalBinTag='/i386cc7'
  PATH="${PATH}:${cern}${OpalBinTag}/${libver}/bin"
elif [ "$HARDWARE" = "i386cc8" -o "$HARDWARE" = "amd64cc8" ]; then
  OpalBinTag='/i386cc8'
  PATH="${PATH}:${cern}${OpalBinTag}/${libver}/bin"
elif [ "$HARDWARE" = "x86_64al9" ]; then
  OpalBinTag='/x86_64al9'
  PATH="${PATH}:${cern}${OpalBinTag}/${libver}/bin"
else
  OpalBinTag=''
fi

## Define CERN global variables
cern_root="${cern}${OpalBinTag}/${libver}" ;                 export cern_root
kernlib="${cern_root}/lib/libkernlib.a" ;     export kernlib
packlib="${cern_root}/lib/libpacklib.a" ;     export packlib
mathlib="${cern_root}/lib/libmathlib.a" ;     export mathlib
graflib="${cern_root}/lib/libgraflib.a" ;     export graflib      
graflibX11="${cern_root}/lib/libgrafX11.a" ;  export graflibX11
# the link script uses $CERN
CERN="${cern}${OpalBinTag}" ; export CERN

PATH="${HOME}/scripts:${otop}/pro${OpalBinTag}/bin:${opal}/scripts:${cern_root}/bin:$PATH"; export PATH
propath=". ${HOME}/car ${HOME}/cra ${HOME}${OpalBinTag}/lib ${HOME}${OpalBinTag}/src ${otop}/pro/src/car ${otop}/pro/src/cra ${otop}/pro${OpalBinTag}/lib"
export propath

allrope="rope dc cv cj jc cz ct cx ce id lm tb pb eb pe ee em hb hp mb me mm fd od ou tr oc dd px su op si cs dx ll cu"
dstrope="rope dc px ou tr oc od cx su ll cu"
export allrope dstrope

